@@ -25,8 +25,43 @@ def singularities(expression, symbol):
     """
     Find singularities of a given function.
 
+    Parameters
+    ==========
+
+    expression : Expr
+        The target function in which singularities need to be found.
+    symbol : Symbol
+        The symbol over the values of which the singularity in
+        expression in being searched for.
+
+    Returns
+    =======
+
+    Set
+        A set of values for ``symbol`` for which ``expression`` has a
+        singularity. An ``EmptySet`` is returned if ``expression`` has no
+        singularities for any given value of ``Symbol``.
+
+    Raises
+    ======
+
+    NotImplementedError
+        The algorithm to find singularities for irrational functions
+        has not been implemented yet.
+
+    Notes
+    =====
+
+    This function does not find non-isolated singularities
+    nor does it find branch points of the expression.
+
     Currently supported functions are:
-    - univariate rational (real or complex) functions
+        - univariate rational (real or complex) functions
+
+    References
+    ==========
+
+    .. [1] https://en.wikipedia.org/wiki/Mathematical_singularity
 
     Examples
     ========
@@ -44,17 +79,6 @@ def singularities(expression, symbol):
     >>> singularities(1/(y**3 + 1), y)
     {-1, 1/2 - sqrt(3)*I/2, 1/2 + sqrt(3)*I/2}
 
-    Notes
-    =====
-
-    This function does not find nonisolated singularities
-    nor does it find branch points of the expression.
-
-    References
-    ==========
-
-    .. [1] http://en.wikipedia.org/wiki/Mathematical_singularity
-
     """
     if not expression.is_rational_function(symbol):
         raise NotImplementedError(
@@ -67,7 +91,7 @@ def singularities(expression, symbol):
 
 
 ###########################################################################
-###################### DIFFERENTIAL CALCULUS METHODS ######################
+#                      DIFFERENTIAL CALCULUS METHODS                      #
 ###########################################################################
 
 
@@ -75,9 +99,32 @@ def monotonicity_helper(expression, predicate, interval=S.Reals, symbol=None):
     """
     Helper function for functions checking function monotonicity.
 
+    Parameters
+    ==========
+
+    expression : Expr
+        The target function which is being checked
+    predicate : function
+        The property being tested for. The function takes in an integer
+        and returns a boolean. The integer input is the derivative and
+        the boolean result should be true if the property is being held,
+        and false otherwise.
+    interval : Set, optional
+        The range of values in which we are testing, defaults to all reals.
+    symbol : Symbol, optional
+        The symbol present in expression which gets varied over the given range.
+
     It returns a boolean indicating whether the interval in which
     the function's derivative satisfies given predicate is a superset
     of the given interval.
+
+    Returns
+    =======
+
+    Boolean
+        True if ``predicate`` is true for all the derivatives when ``symbol``
+        is varied in ``range``, False otherwise.
+
     """
     expression = sympify(expression)
     free = expression.free_symbols
@@ -89,9 +136,9 @@ def monotonicity_helper(expression, predicate, interval=S.Reals, symbol=None):
                 ' for all multivariate expressions.'
             )
 
-    x = symbol or (free.pop() if free else Symbol('x'))
-    derivative = expression.diff(x)
-    predicate_interval = solveset(predicate(derivative), x, S.Reals)
+    variable = symbol or (free.pop() if free else Symbol('x'))
+    derivative = expression.diff(variable)
+    predicate_interval = solveset(predicate(derivative), variable, S.Reals)
     return interval.is_subset(predicate_interval)
 
 
@@ -99,6 +146,24 @@ def is_increasing(expression, interval=S.Reals, symbol=None):
     """
     Return whether the function is increasing in the given interval.
 
+    Parameters
+    ==========
+
+    expression : Expr
+        The target function which is being checked.
+    interval : Set, optional
+        The range of values in which we are testing (defaults to set of
+        all real numbers).
+    symbol : Symbol, optional
+        The symbol present in expression which gets varied over the given range.
+
+    Returns
+    =======
+
+    Boolean
+        True if ``expression`` is increasing (either strictly increasing or
+        constant) in the given ``interval``, False otherwise.
+
     Examples
     ========
 
@@ -124,6 +189,24 @@ def is_strictly_increasing(expression, interval=S.Reals, symbol=None):
     """
     Return whether the function is strictly increasing in the given interval.
 
+    Parameters
+    ==========
+
+    expression : Expr
+        The target function which is being checked.
+    interval : Set, optional
+        The range of values in which we are testing (defaults to set of
+        all real numbers).
+    symbol : Symbol, optional
+        The symbol present in expression which gets varied over the given range.
+
+    Returns
+    =======
+
+    Boolean
+        True if ``expression`` is strictly increasing in the given ``interval``,
+        False otherwise.
+
     Examples
     ========
 
@@ -149,6 +232,24 @@ def is_decreasing(expression, interval=S.Reals, symbol=None):
     """
     Return whether the function is decreasing in the given interval.
 
+    Parameters
+    ==========
+
+    expression : Expr
+        The target function which is being checked.
+    interval : Set, optional
+        The range of values in which we are testing (defaults to set of
+        all real numbers).
+    symbol : Symbol, optional
+        The symbol present in expression which gets varied over the given range.
+
+    Returns
+    =======
+
+    Boolean
+        True if ``expression`` is decreasing (either strictly decreasing or
+        constant) in the given ``interval``, False otherwise.
+
     Examples
     ========
 
@@ -174,6 +275,24 @@ def is_strictly_decreasing(expression, interval=S.Reals, symbol=None):
     """
     Return whether the function is strictly decreasing in the given interval.
 
+    Parameters
+    ==========
+
+    expression : Expr
+        The target function which is being checked.
+    interval : Set, optional
+        The range of values in which we are testing (defaults to set of
+        all real numbers).
+    symbol : Symbol, optional
+        The symbol present in expression which gets varied over the given range.
+
+    Returns
+    =======
+
+    Boolean
+        True if ``expression`` is strictly decreasing in the given ``interval``,
+        False otherwise.
+
     Examples
     ========
 
@@ -197,6 +316,30 @@ def is_monotonic(expression, interval=S.Reals, symbol=None):
     """
     Return whether the function is monotonic in the given interval.
 
+    Parameters
+    ==========
+
+    expression : Expr
+        The target function which is being checked.
+    interval : Set, optional
+        The range of values in which we are testing (defaults to set of
+        all real numbers).
+    symbol : Symbol, optional
+        The symbol present in expression which gets varied over the given range.
+
+    Returns
+    =======
+
+    Boolean
+        True if ``expression`` is monotonic in the given ``interval``,
+        False otherwise.
+
+    Raises
+    ======
+
+    NotImplementedError
+        Monotonicity check has not been implemented for the queried function.
+
     Examples
     ========
 
@@ -224,6 +367,6 @@ def is_monotonic(expression, interval=S.Reals, symbol=None):
             ' for all multivariate expressions.'
         )
 
-    x = symbol or (free.pop() if free else Symbol('x'))
-    turning_points = solveset(expression.diff(x), x, interval)
+    variable = symbol or (free.pop() if free else Symbol('x'))
+    turning_points = solveset(expression.diff(variable), variable, interval)
     return interval.intersection(turning_points) is S.EmptySet
