@@ -137,17 +137,17 @@ attributes of objects/classes.
 References
 ==========
 
-.. [1] http://en.wikipedia.org/wiki/Negative_number
-.. [2] http://en.wikipedia.org/wiki/Parity_%28mathematics%29
-.. [3] http://en.wikipedia.org/wiki/Imaginary_number
-.. [4] http://en.wikipedia.org/wiki/Composite_number
-.. [5] http://en.wikipedia.org/wiki/Irrational_number
-.. [6] http://en.wikipedia.org/wiki/Prime_number
-.. [7] http://en.wikipedia.org/wiki/Finite
+.. [1] https://en.wikipedia.org/wiki/Negative_number
+.. [2] https://en.wikipedia.org/wiki/Parity_%28mathematics%29
+.. [3] https://en.wikipedia.org/wiki/Imaginary_number
+.. [4] https://en.wikipedia.org/wiki/Composite_number
+.. [5] https://en.wikipedia.org/wiki/Irrational_number
+.. [6] https://en.wikipedia.org/wiki/Prime_number
+.. [7] https://en.wikipedia.org/wiki/Finite
 .. [8] https://docs.python.org/3/library/math.html#math.isfinite
 .. [9] http://docs.scipy.org/doc/numpy/reference/generated/numpy.isfinite.html
-.. [10] http://en.wikipedia.org/wiki/Transcendental_number
-.. [11] http://en.wikipedia.org/wiki/Algebraic_number
+.. [10] https://en.wikipedia.org/wiki/Transcendental_number
+.. [11] https://en.wikipedia.org/wiki/Algebraic_number
 
 """
 from __future__ import print_function, division
@@ -189,6 +189,7 @@ _assume_rules = FactRules([
 
     'prime          ->  integer & positive',
     'composite      ->  integer & positive & !prime',
+    '!composite     ->  !positive | !even | prime',
 
     'irrational     ==  real & !rational',
 
@@ -326,10 +327,9 @@ class ManagedProperties(BasicMeta):
 
         defs = {}
         for base in reversed(cls.__bases__):
-            try:
-                defs.update(base._explicit_class_assumptions)
-            except AttributeError:
-                pass
+            assumptions = getattr(base, '_explicit_class_assumptions', None)
+            if assumptions is not None:
+                defs.update(assumptions)
         defs.update(local_defs)
 
         cls._explicit_class_assumptions = defs
@@ -337,10 +337,9 @@ class ManagedProperties(BasicMeta):
 
         cls._prop_handler = {}
         for k in _assume_defined:
-            try:
-                cls._prop_handler[k] = getattr(cls, '_eval_is_%s' % k)
-            except AttributeError:
-                pass
+            eval_is_meth = getattr(cls, '_eval_is_%s' % k, None)
+            if eval_is_meth is not None:
+                cls._prop_handler[k] = eval_is_meth
 
         # Put definite results directly into the class dict, for speed
         for k, v in cls.default_assumptions.items():
@@ -349,10 +348,11 @@ class ManagedProperties(BasicMeta):
         # protection e.g. for Integer.is_even=F <- (Rational.is_integer=F)
         derived_from_bases = set()
         for base in cls.__bases__:
-            try:
-                derived_from_bases |= set(base.default_assumptions)
-            except AttributeError:
-                continue  # not an assumption-aware class
+            default_assumptions = getattr(base, 'default_assumptions', None)
+            # is an assumption-aware class
+            if default_assumptions is not None:
+                derived_from_bases.update(default_assumptions)
+
         for fact in derived_from_bases - set(cls.default_assumptions):
             pname = as_property(fact)
             if pname not in cls.__dict__:
