@@ -1,8 +1,10 @@
-import warnings
-with warnings.catch_warnings():
-    warnings.simplefilter("ignore")
+from sympy.utilities.pytest import ignore_warnings
+from sympy.utilities.exceptions import SymPyDeprecationWarning
+
+with ignore_warnings(SymPyDeprecationWarning):
     from sympy.matrices.densetools import eye
     from sympy.matrices.densearith import add, sub, mulmatmat, mulmatscaler
+
 from sympy import ZZ
 
 
