@@ -53,7 +53,7 @@ class HilbertSpace(Basic):
     References
     ==========
 
-    .. [1] http://en.wikipedia.org/wiki/Hilbert_space
+    .. [1] https://en.wikipedia.org/wiki/Hilbert_space
     """
 
     def __new__(cls):
@@ -254,7 +254,7 @@ class FockSpace(HilbertSpace):
     References
     ==========
 
-    .. [1] http://en.wikipedia.org/wiki/Fock_space
+    .. [1] https://en.wikipedia.org/wiki/Fock_space
     """
 
     def __new__(cls):
@@ -319,7 +319,7 @@ class TensorProductHilbertSpace(HilbertSpace):
     References
     ==========
 
-    .. [1] http://en.wikipedia.org/wiki/Hilbert_space#Tensor_products
+    .. [1] https://en.wikipedia.org/wiki/Hilbert_space#Tensor_products
     """
 
     def __new__(cls, *args):
@@ -465,7 +465,7 @@ class DirectSumHilbertSpace(HilbertSpace):
     References
     ==========
 
-    .. [1] http://en.wikipedia.org/wiki/Hilbert_space#Direct_sums
+    .. [1] https://en.wikipedia.org/wiki/Hilbert_space#Direct_sums
     """
     def __new__(cls, *args):
         r = cls.eval(args)
@@ -582,7 +582,7 @@ class TensorPowerHilbertSpace(HilbertSpace):
     References
     ==========
 
-    .. [1] http://en.wikipedia.org/wiki/Hilbert_space#Tensor_products
+    .. [1] https://en.wikipedia.org/wiki/Hilbert_space#Tensor_products
     """
 
     def __new__(cls, *args):
