@@ -1,5 +1,6 @@
 from sympy.external import import_module
 from sympy import Mul, Integer
+from sympy.core.compatibility import PY3
 from sympy.physics.quantum.dagger import Dagger
 from sympy.physics.quantum.gate import (X, Y, Z, H, CNOT,
         IdentityGate, CGate, PhaseGate, TGate)
@@ -483,10 +484,18 @@ def test_bfs_identity_search():
     assert bfs_identity_search(gate_list, 1, max_depth=4) == id_set
 
 
-@XFAIL
+# @XFAIL
+# Seems to fail on Python 2.7, but not 3.X, unless scipy is installed
 def test_bfs_identity_search_xfail():
+    scipy = import_module('scipy', __import__kwargs={'fromlist': ['sparse']})
+    if scipy:
+        skip("scipy installed.")
     s = PhaseGate(0)
     t = TGate(0)
     gate_list = [Dagger(s), t]
     id_set = {GateIdentity(Dagger(s), t, t)}
     assert bfs_identity_search(gate_list, 1, max_depth=3) == id_set
+
+
+if not PY3:
+    test_bfs_identity_search_xfail = XFAIL(test_bfs_identity_search_xfail)
