@@ -2,13 +2,12 @@
 
 from __future__ import print_function, division
 
+from sympy.core.numbers import Float
 from sympy.polys.domains.field import Field
 from sympy.polys.domains.simpledomain import SimpleDomain
 from sympy.polys.domains.characteristiczero import CharacteristicZero
 from sympy.polys.domains.mpelements import MPContext
-
-from sympy.polys.polyerrors import DomainError, CoercionFailed
-from sympy.core.numbers import Float
+from sympy.polys.polyerrors import CoercionFailed
 from sympy.utilities import public
 
 @public
