@@ -21,8 +21,9 @@ def test_PolyRing___init__():
     assert len(PolyRing(x, ZZ, lex).gens) == 1
     assert len(PolyRing(("x", "y", "z"), ZZ, lex).gens) == 3
     assert len(PolyRing((x, y, z), ZZ, lex).gens) == 3
+    assert len(PolyRing("", ZZ, lex).gens) == 0
+    assert len(PolyRing([], ZZ, lex).gens) == 0
 
-    raises(GeneratorsNeeded, lambda: PolyRing([], ZZ, lex))
     raises(GeneratorsError, lambda: PolyRing(0, ZZ, lex))
 
     assert PolyRing("x", ZZ[t], lex).domain == ZZ[t]
@@ -79,6 +80,9 @@ def test_PolyRing_ring_new():
     assert R.ring_new({(2, 0, 0): 1, (1, 1, 0): 2, (1, 0, 0): 3, (0, 0, 2): 4, (0, 0, 1): 5, (0, 0, 0): 6}) == f
     assert R.ring_new([((2, 0, 0), 1), ((1, 1, 0), 2), ((1, 0, 0), 3), ((0, 0, 2), 4), ((0, 0, 1), 5), ((0, 0, 0), 6)]) == f
 
+    R, = ring("", QQ)
+    assert R.ring_new([((), 7)]) == R(7)
+
 def test_PolyRing_drop():
     R, x,y,z = ring("x,y,z", ZZ)
 
@@ -118,18 +122,31 @@ def test_PolyRing_is_():
     assert R.is_univariate is False
     assert R.is_multivariate is True
 
+    R = PolyRing("", QQ, lex)
+
+    assert R.is_univariate is False
+    assert R.is_multivariate is False
+
 def test_PolyRing_add():
     R, x = ring("x", ZZ)
     F = [ x**2 + 2*i + 3 for i in range(4) ]
 
     assert R.add(F) == reduce(add, F) == 4*x**2 + 24
 
+    R, = ring("", ZZ)
+
+    assert R.add([2, 5, 7]) == 14
+
 def test_PolyRing_mul():
     R, x = ring("x", ZZ)
     F = [ x**2 + 2*i + 3 for i in range(4) ]
 
     assert R.mul(F) == reduce(mul, F) == x**8 + 24*x**6 + 206*x**4 + 744*x**2 + 945
 
+    R, = ring("", ZZ)
+
+    assert R.mul([2, 3, 5]) == 30
+
 def test_sring():
     x, y, z, t = symbols("x,y,z,t")
 
@@ -152,6 +169,12 @@ def test_sring():
     R = PolyRing("x,y,z", Rt, lex)
     assert sring(x + 2*y/t + t**2*z/3, x, y, z) == (R, R.x + 2*R.y/Rt.t + Rt.t**2*R.z/3)
 
+    r = sqrt(2) - sqrt(3)
+    R, a = sring(r, extension=True)
+    assert R.domain == QQ.algebraic_field(r)
+    assert R.gens == ()
+    assert a == R.domain.from_sympy(r)
+
 def test_PolyElement___hash__():
     R, x, y, z = ring("x,y,z", QQ)
     assert hash(x*y*z)
@@ -227,6 +250,9 @@ def test_PolyElement_as_expr():
 
     raises(ValueError, lambda: f.as_expr(X))
 
+    R, = ring("", ZZ)
+    R(3).as_expr() == 3
+
 def test_PolyElement_from_expr():
     x, y, z = symbols("x,y,z")
     R, X, Y, Z = ring((x, y, z), ZZ)
@@ -250,6 +276,10 @@ def test_PolyElement_from_expr():
     raises(ValueError, lambda: R.from_expr(2**x))
     raises(ValueError, lambda: R.from_expr(7*x + sqrt(2)))
 
+    R, = ring("", ZZ)
+    f = R.from_expr(1)
+    assert f == 1 and isinstance(f, R.dtype)
+
 def test_PolyElement_degree():
     R, x,y,z = ring("x,y,z", ZZ)
 
@@ -281,6 +311,10 @@ def test_PolyElement_degree():
     assert (x*y**3 + z).degree(z) == 1
     assert (7*x**5*y**3 + z).degree(z) == 1
 
+    R, = ring("", ZZ)
+    assert R(0).degree() == -oo
+    assert R(1).degree() == 0
+
 def test_PolyElement_tail_degree():
     R, x,y,z = ring("x,y,z", ZZ)
 
@@ -312,6 +346,10 @@ def test_PolyElement_tail_degree():
     assert (x*y**3 + x**3*z).tail_degree(z) == 0
     assert (7*x**5*y**3 + x**3*z).tail_degree(z) == 0
 
+    R, = ring("", ZZ)
+    assert R(0).tail_degree() == -oo
+    assert R(1).tail_degree() == 0
+
 def test_PolyElement_degrees():
     R, x,y,z = ring("x,y,z", ZZ)
 
@@ -345,6 +383,9 @@ def test_PolyElement_coeff():
     raises(ValueError, lambda: f.coeff(-x*y*z))
     raises(ValueError, lambda: f.coeff(7*z**3))
 
+    R, = ring("", ZZ)
+    R(3).coeff(1) == 3
+
 def test_PolyElement_LC():
     R, x, y = ring("x,y", QQ, lex)
     assert R(0).LC == QQ(0)
@@ -363,6 +404,10 @@ def test_PolyElement_LT():
     assert (QQ(1,2)*x).LT == ((1, 0), QQ(1, 2))
     assert (QQ(1,4)*x*y + QQ(1,2)*x).LT == ((1, 1), QQ(1, 4))
 
+    R, = ring("", ZZ)
+    assert R(0).LT == ((), 0)
+    assert R(1).LT == ((), 1)
+
 def test_PolyElement_leading_monom():
     R, x, y = ring("x,y", QQ, lex)
     assert R(0).leading_monom() == 0
@@ -392,6 +437,9 @@ def test_PolyElement_terms():
     assert f.terms() == f.terms(grlex) == f.terms('grlex') == [((1, 7), 1), ((2, 3), 2)]
     assert f.terms(lex) == f.terms('lex') == [((2, 3), 2), ((1, 7), 1)]
 
+    R, = ring("", ZZ)
+    assert R(3).terms() == [((), 3)]
+
 def test_PolyElement_monoms():
     R, x,y,z = ring("x,y,z", QQ)
     monoms = (x**2/3 + y**3/4 + z**4/5).monoms()
@@ -781,6 +829,12 @@ def test_PolyElement_div():
 
     assert f.div(G) == (Q, r)
 
+    R, = ring("", ZZ)
+    assert R(3).div(R(2)) == (0, 3)
+
+    R, = ring("", QQ)
+    assert R(3).div(R(2)) == (QQ(3, 2), 0)
+
 def test_PolyElement_rem():
     R, x = ring("x", ZZ, grlex)
 
@@ -1212,6 +1266,10 @@ def test_PolyElement_is_():
 
     raises(MultivariatePolynomialError, lambda: x.is_cyclotomic)
 
+    R, = ring("", ZZ)
+    assert R(4).is_squarefree is True
+    assert R(6).is_irreducible is True
+
 def test_PolyElement_drop():
     R, x,y,z = ring("x,y,z", ZZ)
 
